fetch_parts

Function fetch_parts 

fn fetch_parts<'g, 'outer>(
    outer: Scope<'outer, Timestamp>,
    scope: Scope<'g, (Timestamp, Subtime)>,
    source_id: GlobalId,
    persist_clients: Arc<PersistClientCache>,
    metadata: CollectionMetadata,
    read_schema: Option<RelationDesc>,
    as_of: Option<Antichain<Timestamp>>,
    snapshot_mode: SnapshotMode,
    until: Antichain<Timestamp>,
    filter_plan: Option<MfpPlan>,
    flow_control: Option<FlowControl<'g, (Timestamp, Subtime)>>,
    listen_sleep: Option<impl Fn() -> RetryParameters + Send + 'static>,
    start_signal: impl Future<Output = ()> + Send + 'static,
    error_handler: ErrorHandler,
) -> (PersistConfig, StreamVec<'g, (Timestamp, Subtime), FetchedBlob<SourceData, (), Timestamp, StorageDiff>>, Vec<PressOnDropButton>)
Fetch the parts of a persist shard a dataflow needs, distributing the work of reading them across all timely workers.